package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.RmsConsigneeMapper;
import com.steerinfo.dil.model.RmsCapacity;
import com.steerinfo.dil.model.RmsConsignee;
import com.steerinfo.dil.service.IRmsConsigneeService;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.framework.mapper.IBaseMapper;
import com.steerinfo.framework.service.impl.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * RmsConsignee服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-12-21 09:47
 * 类描述
 * 修订历史：
 * 日期：2021-12-21
 * 作者：generator
 * 参考：
 * 描述：RmsConsignee服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "rmsConsigneeService")
public class RmsConsigneeServiceImpl implements IRmsConsigneeService {

    @Autowired
    private RmsConsigneeMapper rmsConsigneeMapper;

    
    @Override
    public List<Map<String, Object>> getConsigneeList(Map<String, Object> mapValue) {
        return rmsConsigneeMapper.getConsigneeList(mapValue);
    }

    /*
     * 增加收货客户信息
     * */
    @Override
    public int insertConsignee(Map<String,Object> mapVal) throws ParseException {
        SimpleDateFormat simpleDateFormat=new SimpleDateFormat("yyyy-MM-dd");
        String companyName=(String) mapVal.get("companyName");
        String consigneeAbbreviation=(String)mapVal.get("consigneeAbbreviation");
        String consigneeRegisteredAddress=(String) mapVal.get("consigneeRegisteredAddress");
        String consigneeReceiveAddress=(String) mapVal.get("consigneeReceiveAddress");
        String consigneeContactName=(String) mapVal.get("consigneeContactName");
        String consigneeContactTel=(String)mapVal.get("consigneeContactTel");
        //收货客户父节点
        BigDecimal consigneeFarId=DataChange.dataToBigDecimal(mapVal.get("consigneeFarId"));
        int i=0;
        int rmsConsignees=rmsConsigneeMapper.getConsigneeByCompanyName(companyName);
        RmsConsignee rmsConsignee=new RmsConsignee();
        if(rmsConsignees==0){
            BigDecimal consigneeId = rmsConsigneeMapper.selectConsigneeId();
            rmsConsignee.setConsigneeId(consigneeId);
            rmsConsignee.setConsigneeCompanyName(companyName);
            String consigneeRegistrationTime=(String)mapVal.get("consigneeRegistrationTime");
            //非必填
            if (consigneeAbbreviation!=null) {
                rmsConsignee.setConsigneeAbbreviation(consigneeAbbreviation);
            } if (consigneeRegisteredAddress!=null) {
                rmsConsignee.setConsigneeRegisteredAddress(consigneeRegisteredAddress);
            } if (consigneeReceiveAddress!=null) {
                rmsConsignee.setConsigneeReceiveAddress(consigneeReceiveAddress);
            } if(consigneeRegistrationTime!=null) {
                Date time = simpleDateFormat.parse(consigneeRegistrationTime);
                rmsConsignee.setConsigneeRegistrationTime(time);
            } if (consigneeContactName!=null) {
                rmsConsignee.setConsigneeContactName(consigneeContactName);
            } if (consigneeContactTel!=null) {
                rmsConsignee.setConsigneeContactTel(consigneeContactTel);
            } if (consigneeFarId!=null) {
                rmsConsignee.setConsigneeFarId(consigneeFarId);
            }
            rmsConsignee.setConsigneeCode(DataChange.generateEightDigitsNumber("WL",consigneeId.intValue()));
            rmsConsignee.setDeleted(new BigDecimal(0));
            rmsConsignee.setInsertTime(new Date());
            rmsConsignee.setInsertUsername("admin");
            i+=rmsConsigneeMapper.insertSelective(rmsConsignee);
        }
      else{
          i=-1;
        }
            return  i;
    }

    /*
     * 修改收货客户信息
     * */
    @Override
    public int updateConsignee(Map<String,Object> mapVal) throws ParseException {
        BigDecimal consigneeId=DataChange.dataToBigDecimal(mapVal.get("consigneeId"));
        SimpleDateFormat simpleDateFormat=new SimpleDateFormat("yyyy-MM-dd");
        String companyName=(String) mapVal.get("companyName");
        String consigneeAbbreviation=(String)mapVal.get("consigneeAbbreviation");
        String consigneeRegisteredAddress=(String) mapVal.get("consigneeRegisteredAddress");
        String consigneeReceiveAddress=(String) mapVal.get("consigneeReceiveAddress");
        String consigneeRegistrationTime=(String)mapVal.get("consigneeRegistrationTime");
        RmsConsignee rmsConsignee=new RmsConsignee();
        if(consigneeRegistrationTime!=null){
            Date time = simpleDateFormat.parse(consigneeRegistrationTime);
            rmsConsignee.setConsigneeRegistrationTime(time);
        }else{
            rmsConsignee.setConsigneeRegistrationTime(new Date());
        }

        String consigneeContactName=(String) mapVal.get("consigneeContactName");
        String consigneeContactTel=(String)mapVal.get("consigneeContactTel");
        //收货客户父节点
        BigDecimal consigneeFarId=DataChange.dataToBigDecimal(mapVal.get("consigneeFarId"));

        rmsConsignee.setConsigneeId(consigneeId);
        rmsConsignee.setConsigneeCompanyName(companyName);
        rmsConsignee.setConsigneeAbbreviation(consigneeAbbreviation);
        rmsConsignee.setConsigneeRegisteredAddress(consigneeRegisteredAddress);
        rmsConsignee.setConsigneeReceiveAddress(consigneeReceiveAddress);

        rmsConsignee.setConsigneeContactName(consigneeContactName);
        rmsConsignee.setConsigneeContactTel(consigneeContactTel);
        rmsConsignee.setConsigneeFarId(consigneeFarId);
        rmsConsignee.setUpdateTime(new Date());
        rmsConsignee.setUpdateUsername("admin");
        return rmsConsigneeMapper.updateByPrimaryKeySelective(rmsConsignee);
    }

    /*
     * 删除收货客户信息
     * */
    @Override
    public int deleteConsignee(BigDecimal id) {
        RmsConsignee rmsConsignee = rmsConsigneeMapper.selectByPrimaryKey(id);
        rmsConsignee.setDeleted(new BigDecimal(1));
        return rmsConsigneeMapper.updateByPrimaryKeySelective(rmsConsignee);

    }

    /**
     * 根据id获取收货客户信息
     * @param id
     * @return
     */
    @Override
    public List<Map<String, Object>> getConsigneeById(BigDecimal id) {
        return rmsConsigneeMapper.getConsigneeById(id);
    }


    /*
    * 边输边查收货单位父节点
    * */
    @Override
    public List<Map<String, Object>> getConsigneeFarId(String state) {
        state = "%"+state+"%";
        return rmsConsigneeMapper.getConsigneeFarId(state);
    }

}
